The inline assembly block in s390's chsc() stores that much.

Reviewed-by: Alexander Potapenko <gli...@google.com>
Signed-off-by: Ilya Leoshkevich <i...@linux.ibm.com>
---
 mm/kmsan/instrumentation.c | 7 +++----
 1 file changed, 3 insertions(+), 4 deletions(-)

diff --git a/mm/kmsan/instrumentation.c b/mm/kmsan/instrumentation.c
index cc3907a9c33a..470b0b4afcc4 100644
--- a/mm/kmsan/instrumentation.c
+++ b/mm/kmsan/instrumentation.c
@@ -110,11 +110,10 @@ void __msan_instrument_asm_store(void *addr, uintptr_t 
size)
 
        ua_flags = user_access_save();
        /*
         * Most of the accesses are below 32 bytes. The two exceptions so far
         * are clwb() (64 bytes) and FPU state (512 bytes).
         * It's unlikely that the assembly will touch more than 512 bytes.
         */
-       if (size > 512) {
+       if (size > 4096) {
                WARN_ONCE(1, "assembly store size too big: %ld\n", size);
                size = 8;
        }
@@ -110,11 +110,10 @@ void __msan_instrument_asm_store(void *addr, uintptr_t 
        ua_flags = user_access_save();
        /*
-        * Most of the accesses are below 32 bytes. The two exceptions so far
-        * are clwb() (64 bytes) and FPU state (512 bytes).
-        * It's unlikely that the assembly will touch more than 512 bytes.
+        * Most of the accesses are below 32 bytes. The exceptions so far are
+        * clwb() (64 bytes), FPU state (512 bytes) and chsc() (4096 bytes).
         */
-- 
2.45.1


Reply via email to